@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2018 Osimis S.A., Belgium
+ * Copyright (C) 2017-2019 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -435,7 +435,7 @@ static OrthancPluginErrorCode DecodeImageCallback(OrthancPluginImage** target,
     *target = NULL;
 
     std::string s = "Cannot decode image using GDCM: " + std::string(e.What());
-    OrthancPluginLogError(context_, s.c_str());
+    OrthancPluginLogWarning(context_, s.c_str());
     return OrthancPluginErrorCode_Plugin;
   }
   catch (std::runtime_error& e)
@@ -443,7 +443,7 @@ static OrthancPluginErrorCode DecodeImageCallback(OrthancPluginImage** target,
     *target = NULL;
 
     std::string s = "Cannot decode image using GDCM: " + std::string(e.what());
-    OrthancPluginLogError(context_, s.c_str());
+    OrthancPluginLogWarning(context_, s.c_str());
     return OrthancPluginErrorCode_Plugin;
   }
 }
@@ -614,10 +614,10 @@ extern "C"
       }
 
       if (!scheduler.LookupProperty(webViewerVersion, CacheProperty_WebViewerVersion) ||
-          webViewerVersion != std::string(ORTHANC_WEBVIEWER_VERSION))
+          webViewerVersion != std::string(ORTHANC_PLUGIN_VERSION))
       {
         std::string s = ("The version of the Web viewer plugin has changed from \"" + webViewerVersion + "\" to \"" + 
-                         std::string(ORTHANC_WEBVIEWER_VERSION) + "\": The cache of the Web viewer will be cleared");
+                         std::string(ORTHANC_PLUGIN_VERSION) + "\": The cache of the Web viewer will be cleared");
         OrthancPluginLogWarning(context_, s.c_str());
         clear = true;
       }
@@ -629,7 +629,7 @@ extern "C"
         OrthancPluginLogWarning(context_, "Clearing the cache of the Web viewer");
         scheduler.Clear();
         scheduler.SetProperty(CacheProperty_OrthancVersion, context_->orthancVersion);
-        scheduler.SetProperty(CacheProperty_WebViewerVersion, ORTHANC_WEBVIEWER_VERSION);
+        scheduler.SetProperty(CacheProperty_WebViewerVersion, ORTHANC_PLUGIN_VERSION);
       }
       else
       {
@@ -729,6 +729,6 @@ extern "C"
 
   ORTHANC_PLUGINS_API const char* OrthancPluginGetVersion()
   {
-    return ORTHANC_WEBVIEWER_VERSION;
+    return ORTHANC_PLUGIN_VERSION;
   }
 }
