@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2018 Osimis S.A., Belgium
+ * Copyright (C) 2017-2019 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -90,6 +90,6 @@ namespace OrthancPlugins
 
     ~ImageReader();
 
-    Orthanc::ImageAccessor GetAccessor() const;
+    void GetAccessor(Orthanc::ImageAccessor& target) const;
   };
 }
